@@ -8,15 +8,16 @@ from pydantic import BaseModel, Field
 from pymultirole_plugins.v1.processor import ProcessorBase, ProcessorParameters
 from pymultirole_plugins.v1.schema import Document, Sentence
 from pymultirole_plugins.v1.segmenter import SegmenterParameters, SegmenterBase
-from pysegmenters_pysdb.pysbd_sentencizer import PySBDSentencizer
 from spacy.cli.download import download_model, get_compatibility, get_version
 from spacy.language import Language
 from wasabi import msg
 
+from pysegmenters_pysdb.pysbd_sentencizer import PySBDSentencizer
+
 
 class PySDBSegmenterParameters(SegmenterParameters, ProcessorParameters, ABC):
-    lang: str = Field("en",
-                      description="Name of the 2-letter language of the documents")
+    language: str = Field("xx",
+                          description="Name of the 2-letter language of the documents", extra="language")
 
 
 class PySDBSegmenter(SegmenterBase, ProcessorBase, ABC):
@@ -28,10 +29,12 @@ class PySDBSegmenter(SegmenterBase, ProcessorBase, ABC):
             -> List[Document]:
         params: PySDBSegmenterParameters = \
             cast(PySDBSegmenterParameters, parameters)
-        # Retrieve nlp pipe
-        nlp, enable_pipes = get_sentencizer_from_params(params)
-        with nlp.select_pipes(enable=enable_pipes):
-            for document in documents:
+
+        for document in documents:
+            lang = document_language(doc, params.language)
+            # Retrieve nlp pipe
+            nlp, enable_pipes = get_sentencizer_from_params(lang)
+            with nlp.select_pipes(enable=enable_pipes):
                 document.sentences = []
                 doc = nlp(document.text)
                 if doc.has_annotation("SENT_START"):
@@ -50,8 +53,14 @@ class PySDBSegmenter(SegmenterBase, ProcessorBase, ABC):
         return PySDBSegmenterParameters
 
 
-def get_sentencizer_from_params(params):
-    return get_pysbd_sentencizer(params.lang, ttl_hash=get_ttl_hash())
+def document_language(doc: Document, default: str=None):
+    if doc.metadata is not None and 'language' in doc.metadata:
+        lang = doc.metadata['language']
+    return default
+
+
+def get_sentencizer_from_params(lang):
+    return get_pysbd_sentencizer(lang, ttl_hash=get_ttl_hash())
 
 
 # Deprecated model shortcuts, only used in errors and warnings
@@ -102,7 +111,7 @@ def load_spacy_model(model, exclude, *pip_args):
         model_name = MODEL_SHORTCUTS[model]
     compatibility = get_compatibility()
     if model_name not in compatibility:
-        msg.fail(
+        msg.warn(
             f"No compatible package found for '{model}' (spaCy v{spacy.about.__version__}), fallback to blank model")
         return spacy.blank(model_name)
     else:
